/*

Visual Studio-like style based on original C# coloring by Jason Diamond <jason@diamond.name>

*/
pre code {
  display: block; padding: 0.5em;
}

pre .comment,
pre .annotation,
pre .template_comment,
pre .diff .header,
pre .chunk,
pre .apache .cbracket {
  color: rgb(0, 128, 0);
}

pre .keyword,
pre .id,
pre .built_in,
pre .smalltalk .class,
pre .winutils,
pre .bash .variable,
pre .tex .command,
pre .request,
pre .status,
pre .nginx .title {
  color: rgb(0, 0, 255);
}

pre .string,
pre .title,
pre .parent,
pre .tag .value,
pre .rules .value,
pre .rules .value .number,
pre .ruby .symbol,
pre .ruby .symbol .string,
pre .ruby .symbol .keyword,
pre .ruby .symbol .keymethods,
pre .instancevar,
pre .aggregate,
pre .template_tag,
pre .django .variable,
pre .addition,
pre .flow,
pre .stream,
pre .apache .tag,
pre .date,
pre .tex .formula {
  color: rgb(163, 21, 21);
}

pre .ruby .string,
pre .decorator,
pre .filter .argument,
pre .localvars,
pre .array,
pre .attr_selector,
pre .pseudo,
pre .pi,
pre .doctype,
pre .deletion,
pre .envvar,
pre .shebang,
pre .preprocessor,
pre .userType,
pre .apache .sqbracket,
pre .nginx .built_in,
pre .tex .special,
pre .input_number {
  color: rgb(43, 145, 175);
}

pre .phpdoc,
pre .javadoc,
pre .xmlDocTag {
  color: rgb(128, 128, 128);
}

pre .vhdl .typename { font-weight: bold; }
pre .vhdl .string { color: #666666; }
pre .vhdl .literal { color: rgb(163, 21, 21); }
pre .vhdl .attribute { color: #00B0E8; }
