{% extends "base.html" %}
{% block container %}
    <div class="sidebar">
        {% block sidebar %}{% endblock %}
    </div>
    <div class="content">
        {% block content %}{% endblock %}
    </div>
{% endblock %}
