{% load i18n %}{% autoescape off %}
{% blocktrans %}You're receiving this email because subscribed to comments to {{ article_link }}.{% endblocktrans %}<br />
<br />
{% if comment_guest_name %}{% blocktrans %}The user "{{ comment_guest_name }}" say:{% endblocktrans %}<br />{% endif %}
<blockquote>{{ comment_text_html|linebreaks|safe }}</blockquote>
<br />
{% trans "Comment published:" %} {{ comment_created }}<br />
<br />
{% trans "To unsubscribe, go to:" %}
<a href="http://{{ site_domain }}{{ unsubscribe_url }}">http://{{ site_domain }}{{ unsubscribe_url }}</a><br />
<br />
---<br />
{{ sign }}
{% endautoescape %}
