body {
    background-color: #F6F6F6;
    color: #444444;
    margin: 0 auto;
    max-width: 960px;
    min-width: 600px;
    padding: 0 20px;
}
a {
    color: #660000;
}
img {
    border: none;
}
h1, h2, h3, h4, h5 {color: #660000;}
h3 {font-size: 140%;}
h4 {font-size: 120%;}
h5 {font-size: 110%; margin: 10px 0px 0px 0px;}
hr {
    border: solid 1px #eeeeee;
}
blockquote {
    border-color: #F6F6F6 #F6F6F6 #F6F6F6 #C3D9FF;
    border-style: solid;
    border-width: 2px;
    margin: 0 30px 20px;
    padding: 0 0 0 10px;
}

tt {
    background-color: #F8F8F8;
    border: 1px solid #EAEAEA;
    border-radius: 3px 3px 3px 3px;
    font-size: 120%;
    margin: 0 2px;
    padding: 0 5px;
    white-space: nowrap;
}

tt.more {
    font-size: 16pt;
    padding: 5px 10px;
}
    tt.more a {
        text-decoration: none;
    }

.site-title {
    float: left;
}
    .site-title h1 {
        margin: 15px 0;
    }
    .site-title a {
        background-color: #660000;
        color: white;
        margin: 5px 0;
        padding: 7px;
        text-decoration: none;
    }

.site-search {
    float: right;
    padding-top: 7px;
}
    .site-search input {
        padding: 3px;
    }
    .site-search input.query-string {
        width: 230px;
    }

.search-block {
    width: 800px;
    height: 50px;
}
    .search-block .query-string {
        width: 400px;
    }


.site-langs {
    padding-top: 5px;
}

.sidebar {
    float: right;
    width: 200px;
    margin-top: 40px;
    padding-left: 10px;
    text-align: right;
}
    .sidebar ul {
        margin: 0;
        padding: 0;
        list-style: none;
    }
    .sidebar .categories-list li {
        margin-bottom: 6px;
        list-style-image: url('/static/images/chevron-right.png');
        list-style-position: inside;
    }
    .sidebar .tags-list li {
        display: inline;
        white-space: nowrap;
    }

.tag_item {
    color: #664e4e;
}

.site-menu ul {
    padding: 0;
    margin-top: 0;
}
    .site-menu ul li {
        list-style: none;
        display: inline;
        padding-right: 4px;
    }

.alignleft {
    float: left;
}
.alignright {
    float: right;
}
.alignnone {
    clear: both;
    display: block;
}
.whitespace {
    margin: 0px 0px 10px 10px;
}
.dotted {
    padding: 2px;
    border: dotted #c4c4c4 2px;
}

.articles table td {
    vertical-align: middle;
    padding-bottom: 10px;
}
.article-published {
    text-align: right;
    width: 170px;
    color: gray;
    padding-right: 10px;
}
    .article-published h2 {
        margin: 0px;
    }

.article-title a {
    color: #660000;
    text-decoration: none;
    font-size: 1.2em;
}
    .article-title h1 a {
        font-size: 20pt;
    }

.article-text {
    font-family: sans-serif;
    line-height: 1.3em;
}
    .article-text iframe {
        display: block;
    }
    .article-text h1, .article-text h2, .article-text h3, .article-text h4 {
        color: #660000;
    }

.footer {
    padding: 30px 0;
}



.article-title h1 {
    margin-bottom: 0;
}
.article-meta {
    color: rgba(0, 0, 0, 0.6);
}
    .article-meta a {
        color: rgba(5, 85, 128, 0.6);
    }

.comments > ul {
    padding: 0;
}
    .comments > ul > li {
        list-style-type: none;
    }
    .comments .alt {
        padding: 0.5em;
        margin-bottom: 10px;
        border-top: none !important;
        border-right: none !important;
    }
    .comments .alt1 {
        border-left: 10px solid rgba(5, 55, 80, .2);
        border-bottom: 4px solid rgba(5, 55, 80, .2);
    }
    .comments .alt2 {
        border-left: 10px solid rgba(255, 74, 0, .2);
        border-bottom: 4px solid rgba(255, 74, 0, .2);
    }

.comment-username {
    font-weight: bold;
    color: #660000;
    overflow: hidden;
}
    .comment-username a {
        color: #660000;
    }
.comment-text {
    margin-bottom: 30px;
}
.comment-meta {
    float: right;
    color: gray;
    padding-left: 10px;
}
.comment-date-approved a {
    padding-left: 5px;
    color: rgba(5, 55, 80, .4);
}
#comment-form {
    float: left;
    width: 780px;
}
.comment-form-label {
    width: 60px;
    float: left;
}
.comment-form-input input {
    width: 300px;
}
.comment-form-input textarea {
    width: 100%;
    height: 170px;
}
    .comment-form-input .form-error {
        border: solid 1px red;
        margin: 2px 1px;
    }

blockquote.download {
    background: url("/static/images/download.gif") no-repeat scroll left top #D4FFC6;
    border: 10px solid #ade899;
    color: #000000;
    margin: 0;
    padding: 10px 10px 25px 50px;
}
blockquote.info {
    background: url("/static/images/info.gif") no-repeat scroll left top #fef5bd;
    border: 10px solid #f6e08a;
    color: #000000;
    margin: 10px 0;
    padding: 2px 10px 25px 50px;
}
i.smorg_star {
    background: url("/static/images/smorg_star.png") no-repeat scroll left bottom;
    display: inline-block;
    height: 16px;
    width: 16px;
}
