{% extends "base_without_sidebar.html"%}
{% load static i18n %}

{% block title %}{{ category.title }}{% endblock %}

{% block content %}
    <div class="articles">
        <table>
           {% include "marcus/blocks/articles.html" with articles=object_list %}
        </table>
    </div>
{% endblock %}
