{% extends "base_without_sidebar.html" %}
{% load i18n marcus_markdown %}

{% block title %}{% trans flatpage.title %}{% endblock %}

{% block content %}
    <h1>{% trans flatpage.title %}</h1>
    <p>{{ flatpage.content|markdown }}</p>
{% endblock %}
