{% extends "base_with_sidebar.html"%}
{% load static i18n %}

{% block title %}{% trans "Categories" %}{% endblock %}

{% block content %}
    <ul>
        {% for category in object_list %}
            <li><a href="{{ category.get_absolute_url }}">{{ category }}</a></li>
        {% endfor %}
    </ul>
{% endblock %}
