{% extends "base_with_sidebar.html"%}
{% load i18n l10n marcus_tags %}

{% block title %}{% trans "Spam detected" %}{% endblock %}

{% block content %}
    <p>{% trans "We decided that this comment is spam!" %}</p>
    <blockquote>{{ text|linebreaks }}</blockquote>
    <p>{% trans "Please fix it..." %}</p>
{% endblock %}
