/* -------------------------------------------------------------------
// markItUp!
// By Jay Salvat - http://markitup.jaysalvat.com/
// ------------------------------------------------------------------*/

.markItUp .markItUpButton1 a {
    background-image: url(images/h1.png);
}
.markItUp .markItUpButton2 a {
    background-image: url(images/h2.png);
}
.markItUp .markItUpButton3 a {
    background-image: url(images/h3.png);
}
.markItUp .markItUpButton4 a {
    background-image: url(images/h4.png);
}
.markItUp .markItUpButton5 a {
    background-image: url(images/h5.png);
}
.markItUp .markItUpButton6 a {
    background-image: url(images/h6.png);
}
.markItUp .markItUpButton7 a {
    background-image: url(images/bold.png);
}
.markItUp .markItUpButton8 a {
    background-image: url(images/italic.png);
}
.markItUp .markItUpButton9 a {
    background-image: url(images/list-bullet.png);
}
.markItUp .markItUpButton10 a {
    background-image: url(images/list-numeric.png);
}
.markItUp .markItUpButton11 a {
    background-image: url(images/picture.png);
}
.markItUp .markItUpButton12 a {
    background-image: url(images/link.png);
}
.markItUp .markItUpButton13 a {
    background-image: url(images/quotes.png);
}
.markItUp .markItUpButton14 a {
    background-image: url(images/code.png);
}
.markItUp .preview a {
    background-image: url(images/preview.png);
}
.markItUp .fullScreen a {
    background-image: url(images/fullscreen.png);
}
.markItUp-fullScreen {
    position: absolute;
    top: 0;
    left: 0;
    margin: 0;
    height: 100%;
    width: 100%;
    z-index: 9999;
    background: #f0f0f0;
}
.markItUp-fullScreen .markItUpContainer {
    padding: 20px 40px 40px;
}
.ws-size > a {
    background-image: url(images/ws-size.png);
}
.ws-size ul {
    border: none !important;
    margin: 0px !important;
    padding: 0px !important;
}
.ws-size li {
    border: none !important;
}
.ws-size li a {
    width: 30px !important;
    padding: 4px 8px 4px 8px !important;
}
.ws-size ul a:hover {
    background-color: #c4c4c4;
}
.ws-size .ws-size-item a {
    font-size: 12px;
}
